(PackageInfo named: 'ScheduledOSCalls') preamble: '"below, add code to be run before the loading of this package"'!
SystemOrganization addCategory: #ScheduledOSCalls!

Object subclass: #ScheduledOSCall
	instanceVariableNames: 'date time dayOfWeek command title lastOSCallResult active'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'ScheduledOSCalls'!

!ScheduledOSCall commentStamp: 'LL 2/21/2013 11:06' prior: 0!
Data for sending commands to the OS at a given time.  Click ? between instance and class buttoms to read more.

Create an instance of this class for each command (and parameters) and the time to send the command and scheduling cycle.

See the method comments for more info on each.

Also see the class comment of ScheduledOSCallMgr for info on how it holds instances of this class and how it calls OSProcess with the command at the appointed time.!

!ScheduledOSCall class methodsFor: 'instance creation' stamp: 'LL 2/11/2013 17:19'!
fromString: aString
	"Create a new instance from the string.  The string is in four parts seperated by pipes '|'."
	"title | time | dayOfWeek | command"
	| parts title time dayOfWeek command |

	parts := (aString subStrings: '|') collect: [:ss | ss withBlanksTrimmed].
	(parts size >= 1) ifTrue: [title := parts first].
	(parts size >= 2) ifTrue: [time := ([Time fromString: parts second] on: Error do: [])].
	(parts size >= 3) ifTrue: [dayOfWeek := parts third onlyLetters asLowercase capitalized asSymbol].
	(parts size >= 4) ifTrue: [command := parts fourth].

	^(self new) title: title; time: time; dayOfWeek: dayOfWeek; command: command; schedule; yourself.
! !

!ScheduledOSCall class methodsFor: 'instance creation' stamp: 'LL 2/11/2013 10:40'!
title: aString time: aTime dayOfWeek: aSymbol command: commandString
	"Create a new instance and set some values."

	^(self new) title: aString; time: aTime; dayOfWeek: aSymbol; command: commandString; schedule; yourself.
! !

!ScheduledOSCall class methodsFor: 'instance creation' stamp: 'LL 2/11/2013 14:41'!
title: aString timeString: timeString dayOfWeek: aSymbol command: commandString
	"Create a new instance and set some values."
	| time |

	time := [Time fromString: timeString] on: Error do: [].
	^(self new) title: aString; time: time; dayOfWeek: aSymbol; command: commandString; schedule; yourself.
! !

!ScheduledOSCall methodsFor: 'Control' stamp: 'LL 2/6/2013 13:48'!
= aScheduledOSCall
	"Answer tue if we have the same hash."

	^self hash = aScheduledOSCall hash.
! !

!ScheduledOSCall methodsFor: 'InstanceVariables' stamp: 'LL 2/19/2013 16:28'!
activate
	"Set active true, if the command is active it will be run at the defined time."

	active := true.
! !

!ScheduledOSCall methodsFor: 'InstanceVariables' stamp: 'LL 2/19/2013 16:28'!
active
	"If true, the command is active and will be run at the defined time."

	active isNil ifTrue: [active := true].
	^active.
! !

!ScheduledOSCall methodsFor: 'InstanceVariables' stamp: 'LL 2/19/2013 16:28'!
active: aBoolean
	"If true, the command is active and will be run at the defined time."

	active := aBoolean.
! !

!ScheduledOSCall methodsFor: 'Control' stamp: 'LL 2/19/2013 16:16'!
callOS
	"Call the OS to run the command."

	lastOSCallResult := OSProcess command: self command.
	self schedule.
	^lastOSCallResult.
! !

!ScheduledOSCall methodsFor: 'InstanceVariables' stamp: 'LL 2/11/2013 10:35'!
command
	"Command to send to the OS."

	command isNil ifTrue: [command := 'help'].
	^command.
! !

!ScheduledOSCall methodsFor: 'InstanceVariables' stamp: 'LL 2/19/2013 16:29'!
command: aString
	"The command to be sent to the OS."

	command := aString.
! !

!ScheduledOSCall methodsFor: 'InstanceVariables' stamp: 'LL 2/6/2013 10:54'!
date
	"The date the command should be sent next."

	date isNil ifTrue: [date := Date today].
	^date.
! !

!ScheduledOSCall methodsFor: 'InstanceVariables' stamp: 'LL 2/6/2013 10:54'!
date: aDate
	"The date the command should be sent next."

	date := aDate.
! !

!ScheduledOSCall methodsFor: 'InstanceVariables' stamp: 'LL 2/18/2013 11:47'!
dayOfWeek
	"A symbol defining the day-of-week the command should be sent."
	"#Sunday #Monday #Tuesday #Wednesday #Thursday #Friday #Saturday #Weekdays #Weekend #Everyday"

	dayOfWeek isNil ifTrue: [dayOfWeek := self date weekday].
	^dayOfWeek.
! !

!ScheduledOSCall methodsFor: 'InstanceVariables' stamp: 'LL 2/18/2013 11:48'!
dayOfWeek: aSymbol
	"A symbol defining the day-of-week the command should be sent."
	"#Sunday #Monday #Tuesday #Wednesday #Thursday #Friday #Saturday #Weekdays #Weekend #Everyday"

	(#(#Sunday #Monday #Tuesday #Wednesday #Thursday #Friday #Saturday #Weekdays #Weekend #Everyday)
		includes: aSymbol) ifTrue: [dayOfWeek := aSymbol].
! !

!ScheduledOSCall methodsFor: 'Control' stamp: 'LL 2/18/2013 11:48'!
everyDay
	"Answer true if the dayOfWeek symbol is #Everyday"

	^self dayOfWeek = #Everyday.
! !

!ScheduledOSCall methodsFor: 'Control' stamp: 'LL 2/11/2013 11:45'!
hash
	"Answer our hash"

	^self when hash.
! !

!ScheduledOSCall methodsFor: 'InstanceVariables' stamp: 'LL 2/19/2013 16:42'!
hold
	"Set active false, if the command is active it will be sent at the defined time."

	active := false.
! !

!ScheduledOSCall methodsFor: 'InstanceVariables' stamp: 'LL 2/7/2013 11:50'!
lastOSCallResult
	"The result of the last OSCall."

	^lastOSCallResult.
! !

!ScheduledOSCall methodsFor: 'Control' stamp: 'LL 2/6/2013 11:08'!
onDay
	"Answer true if the dayOfWeek symbol is one of the weekdays"
	"#Sunday #Monday #Tuesday #Wednesday #Thursday #Friday #Saturday."

	^Week dayNames includes: self dayOfWeek.
! !

!ScheduledOSCall methodsFor: 'Control' stamp: 'LL 2/6/2013 11:46'!
onWeekdays
	"Answer true if the dayOfWeek symbol is #Weekdays."

	^self dayOfWeek = #Weekdays.
! !

!ScheduledOSCall methodsFor: 'Control' stamp: 'LL 2/6/2013 11:09'!
onWeekend
	"Answer true if the dayOfWeek symbol is #Weekend."

	^self dayOfWeek = #Weekend.
! !

!ScheduledOSCall methodsFor: 'InstanceVariables' stamp: 'LL 2/11/2013 14:44'!
printOn: aStream
	"Print our values on the stream."
	| showSeconds |

	aStream
		nextPutAll: 'Title: "'; nextPutAll: self title; nextPutAll: '" - Is '; nextPutAll: (self active ifTrue: ['Active'] ifFalse: ['InActive']); cr;
		nextPutAll: 'Command: "'; nextPutAll: self command; nextPutAll: '"'; cr.

	self everyDay ifTrue: [aStream nextPutAll: 'Every Day'].
	self onDay ifTrue: [aStream nextPutAll: 'Every: '; nextPutAll: self dayOfWeek asString].
	self onWeekdays ifTrue: [aStream nextPutAll: 'On weekdays'].
	self onWeekend ifTrue: [aStream nextPutAll: 'On weekends'].

	aStream nextPutAll: ', next on: '.
	self date dayMonthYearDo: [:d :m :y |
		aStream nextPutAll: (Date nameOfMonth: m); nextPutAll: ' '.
		d printOn: aStream.
		aStream nextPutAll: ', '.
		y printOn: aStream.
	].
	aStream nextPutAll: ' at: '.
	showSeconds := self time asDuration seconds ~= 0.
	self time print24: false showSeconds: showSeconds on: aStream..
	aStream cr.
	lastOSCallResult notNil ifTrue: [aStream nextPutAll: 'Last attempt: ';
		nextPutAll: (lastOSCallResult succeeded ifTrue: ['Succeded'] ifFalse: ['Failed'])
	] ifFalse: [aStream nextPutAll: 'Not attempted yet'].
	aStream cr; cr.
! !

!ScheduledOSCall methodsFor: 'Control' stamp: 'LL 2/19/2013 16:45'!
schedule
	"Adjust the date the command should be sent next.  This will be sometime later than the current date/time."
	| dateTime now weekdayIndex |

	dateTime := DateAndTime date: self date time: self time.
	weekdayIndex := date weekdayIndex.
	now := DateAndTime now.

	[
		(dateTime > now) &
			((self onDay & (date weekday = self dayOfWeek)) |
			(self onWeekdays & (weekdayIndex between: 2 and: 6)) |
			(self onWeekend & ((weekdayIndex = 1) | (weekdayIndex = 7))) |
			(self everyDay))
	] whileFalse: [
		date := date addDays: 1.
		dateTime := DateAndTime date: self date time: self time.
		weekdayIndex := date weekdayIndex.
	].
! !

!ScheduledOSCall methodsFor: 'InstanceVariables' stamp: 'LL 2/6/2013 10:58'!
time
	"The time the command should be sent."

	time isNil ifTrue: [time := Time now].
	^time.
! !

!ScheduledOSCall methodsFor: 'InstanceVariables' stamp: 'LL 2/6/2013 10:58'!
time: aTime
	"The time the command should be sent."

	time := aTime.
! !

!ScheduledOSCall methodsFor: 'InstanceVariables' stamp: 'LL 2/6/2013 10:59'!
title
	"The title of this request."

	title isNil ifTrue: [title := '?'].
	^title.
! !

!ScheduledOSCall methodsFor: 'InstanceVariables' stamp: 'LL 2/6/2013 10:59'!
title: aString
	"The title of this request."

	title := aString.
! !

!ScheduledOSCall methodsFor: 'Control' stamp: 'LL 2/19/2013 16:46'!
when
	"Answer a string that is a short description of when we should run.  It is used to identify us."
	| stream showSeconds |

	stream := ReadWriteStream on: ''.
	stream nextPutAll: self dayOfWeek; nextPutAll: ' at '.
	showSeconds := (self time asDuration seconds = 0) not.
	self time print24: false showSeconds: showSeconds on: stream..
	^stream contents.
! !

Object subclass: #ScheduledOSCallMgr
	instanceVariableNames: 'requests process title osCallTestDelay osCallTestLimit osCallRetryLimit'
	classVariableNames: 'OSCallRetryLimitDefault OSCallTestDelayDefault OSCallTestLimitDefault RunningScheduledOSCallMgrs'
	poolDictionaries: ''
	category: 'ScheduledOSCalls'!

!ScheduledOSCallMgr commentStamp: 'LL 3/1/2013 10:26' prior: 0!
Class to hold instances of ScheduledOSCall and run them. Click ? between instance and class buttoms to read more.

An instance of this class is used to hold a group of similar ScheduledOSCall instances.  What constitutes similar is completely subjective.  You can put all of your scheduled OS calls in one instance.  But if you have more than one group of similar calls, keeping them in sperate instances of this class can be helpful.

The class side of this class keeps a dictionary of instances of this class (by their title) that are currently running (checking their instances of ScheduledOSCall for items that are due to run).  This could have been done with a singleton of a third class but then the class side is a singleton so I went with it.  The dictionary allows you to find a given instance of this class (a group of similar ScheduledOSCall instances) and see how it (and its charges) are doing.

Below is a sample.  Please note it builds calls to the LIRC irsend command.  This is only an example.  The ScheduledOSCall and ScheduledOSCalls classes don't know or care about irsend.  They are OS command agnostic.

	| schedule |
	schedule := ScheduledOSCallMgr title: 'Lou''s recordings'.
	schedule addRequest: (ScheduledOSCall fromString: 'Up the volume | 13:29 | #Everyday | irsend SEND_START Explorer4200 vUp; sleep 5; irsend SEND_STOP Explorer4200 vUp').
	schedule addRequest: (ScheduledOSCall fromString: 'Charlie Rose (13) | 13:30 | #Weekdays | irsend SEND_ONCE Explorer4200 0 0 1 3').
	schedule addRequest: (ScheduledOSCall fromString: 'Science (170) | 20:00 | #Tuesday | irsend SEND_ONCE Explorer4200 0 1 7 0').
	schedule addRequest: (ScheduledOSCall fromString: 'Continuum (48) | 20:00 | #Monday | irsend SEND_ONCE Explorer4200 0 0 4 8').
	schedule run.
	schedule requests.

Inspecting the code above will set up an instance of ScheduledOSCalls with four (4) instances of ScheduledOSCall.  The last line will allow you to see the status of each instance of ScheduledOSCall.

There are other ways to create instances of ScheduledOSCall.  The one shown above was chosen to simplify the example.

Use ScheduledOSCalls>terminateAll to terminate all instances of ScheduledOSCallMgr..
Inspect ScheduledOSCalls>runningScheduledOSCallMgr to see the dictionary of ScheduledOSCallMgr.

To find the instance of ScheduledOSCallMgr managing a specific group of ScheduledOSCallMgr and see its requests, inspect the following:

| schedule |
schedule := ScheduledOSCalls at: 'Lou''s recordings'.
schedule ifNotNil: [:s | s requests].

To terminate/remove it:
(ScheduledOSCallMgr at: 'Lou''s recordings') terminate.

Look at instance variables: osCallTestDelay, osCallTestLimit and osCallRetryLimit to see how command calls to OSProcess>command: (callOS: and callOS) are managed.

!

!ScheduledOSCallMgr class methodsFor: 'Control' stamp: 'LL 3/1/2013 09:48'!
addRunningScheduledOSCallMgr: aScheduledOSCallMgr
	"Add the ScheduledOSCallMgr."

	self runningScheduledOSCallMgrs at: aScheduledOSCallMgr title put: aScheduledOSCallMgr.
	SmalltalkImage current addToStartUpList: self.
	^RunningScheduledOSCallMgrs.
! !

!ScheduledOSCallMgr class methodsFor: 'Control' stamp: 'LL 2/21/2013 11:14'!
at: aString
	"Answer the ScheduledOSCallMgr at the title."

	^self runningScheduledOSCallMgrs at: aString ifAbsent: [].
! !

!ScheduledOSCallMgr class methodsFor: 'Control' stamp: 'LL 3/1/2013 09:50'!
clearRunningScheduledOSCallMgrs
	"A collection of ScheduledOSCallMgr objects."

	RunningScheduledOSCallMgrs := Dictionary new.
	SmalltalkImage current removeFromStartUpList: self.
! !

!ScheduledOSCallMgr class methodsFor: 'class variables' stamp: 'LL 2/15/2013 15:12'!
osCallRetryLimitDefault
	"Answer the default value for osCallRetryLimit, the number of time we try the command."

	OSCallRetryLimitDefault isNil ifTrue: [OSCallRetryLimitDefault := 10].
	^OSCallRetryLimitDefault.
! !

!ScheduledOSCallMgr class methodsFor: 'class variables' stamp: 'LL 2/15/2013 15:12'!
osCallRetryLimitDefault: anInt
	"Answer the default value for osCallRetryLimit, the number of time we try the command."

	OSCallRetryLimitDefault := anInt.
! !

!ScheduledOSCallMgr class methodsFor: 'class variables' stamp: 'LL 2/15/2013 15:10'!
osCallTestDelayDefault
	"Answer the default value for osCallTestDelay, the time in milliseconds between testing to see if the command finished."

	OSCallTestDelayDefault isNil ifTrue: [OSCallTestDelayDefault := 200].
	^OSCallTestDelayDefault.
! !

!ScheduledOSCallMgr class methodsFor: 'class variables' stamp: 'LL 2/15/2013 15:10'!
osCallTestDelayDefault: anInt
	"Answer the default value for osCallTestDelay, the time in milliseconds between testing to see if the command finished."

	OSCallTestDelayDefault := anInt.
! !

!ScheduledOSCallMgr class methodsFor: 'class variables' stamp: 'LL 2/15/2013 15:11'!
osCallTestLimitDefault
	"Answer the default value for osCallTestLimit, number of time we test to see if the command finished."

	OSCallTestLimitDefault isNil ifTrue: [OSCallTestLimitDefault := 50].
	^OSCallTestLimitDefault.
! !

!ScheduledOSCallMgr class methodsFor: 'class variables' stamp: 'LL 2/15/2013 15:11'!
osCallTestLimitDefault: anInt
	"Answer the default value for osCallTestLimit, number of time we test to see if the command finished."

	OSCallTestLimitDefault := anInt.
! !

!ScheduledOSCallMgr class methodsFor: 'Control' stamp: 'LL 3/1/2013 10:02'!
removeScheduledOSCallMgr: aScheduledOSCallMgr
	"Remove the ScheduledOSCallMgr from runningScheduledOSCallMgrs."

	self runningScheduledOSCallMgrs removeKey: aScheduledOSCallMgr title ifAbsent: [].
	self runningScheduledOSCallMgrs isEmpty ifTrue: [SmalltalkImage current removeFromStartUpList: self].
	^RunningScheduledOSCallMgrs.
! !

!ScheduledOSCallMgr class methodsFor: 'Control' stamp: 'LL 3/1/2013 10:14'!
removeScheduledOSCallMgrNamed: aTitle
	"Remove the ScheduledOSCallMgr from runningScheduledOSCallMgrs."

	self runningScheduledOSCallMgrs removeKey: aTitle ifAbsent: [].
	self runningScheduledOSCallMgrs isEmpty ifTrue: [SmalltalkImage current removeFromStartUpList: self].
	^RunningScheduledOSCallMgrs.
! !

!ScheduledOSCallMgr class methodsFor: 'class variables' stamp: 'LL 2/21/2013 10:56'!
runningScheduledOSCallMgrs
	"A collection of ScheduledOSCallMgr objects."

	RunningScheduledOSCallMgrs isNil ifTrue: [RunningScheduledOSCallMgrs := Dictionary new].
	^RunningScheduledOSCallMgrs.
! !

!ScheduledOSCallMgr class methodsFor: 'Control' stamp: 'LL 3/1/2013 09:45'!
startUp
	"Called when image is started.  Schedule all the ScheduledOSCall objects in all the ScheduledOSCallMgr objects."

	self runningScheduledOSCallMgrs do: [:sm | sm scheduleAll].
! !

!ScheduledOSCallMgr class methodsFor: 'Control' stamp: 'LL 2/21/2013 11:01'!
terminateAll
	"Terminate all the ScheduledOSCallMgr objects."

	self runningScheduledOSCallMgrs do: [:s | s terminate; clearRequests].
	self clearRunningScheduledOSCallMgrs.
! !

!ScheduledOSCallMgr class methodsFor: 'class initialization' stamp: 'LL 2/6/2013 15:55'!
title: aString
	"Create a new instance with the title."

	^(self new) title: aString; yourself.
! !

!ScheduledOSCallMgr methodsFor: 'comparing' stamp: 'LL 2/21/2013 10:52'!
= aScheduledOSCallMgr
	"Answer true if our titles are the same."

	^self title sameAs: aScheduledOSCallMgr title.
! !

!ScheduledOSCallMgr methodsFor: 'Control' stamp: 'LL 2/19/2013 16:58'!
addAllRequests: aCollection
	"Add all the requests to our requests.  A dictionary of instances of ScheduledOSCall that we run at their time."

	aCollection do: [:r | self requests addRequest: r].
! !

!ScheduledOSCallMgr methodsFor: 'Control' stamp: 'LL 2/19/2013 16:57'!
addRequest: aRequest
	"Add the request to our requests.  A dictionary of instances of ScheduledOSCall that we run at their time."

	self requests at: aRequest when put: aRequest.
! !

!ScheduledOSCallMgr methodsFor: 'Control' stamp: 'LL 2/19/2013 16:24'!
callOS: item
	"Tell the item to call the OS to run the command."
	"The command may take a while to run, so we loop on checking to see if it finished
		delaying for osCallTestDelay milliseconds between each try
		but give up after osCallTestCnt attempts."
	"If it didn't finish successfully, we try again for osCallTestCnt times.  The item will re-schedule itself."
	| delay lastOSCallResult tryCnt checkCnt |

	delay := Delay forMilliseconds: self osCallTestDelay.
	tryCnt := 0.
	[
		lastOSCallResult := item callOS.
		checkCnt := 0.
		[
			delay wait.
			(lastOSCallResult isComplete) | (checkCnt > self osCallTestLimit).
		] whileFalse: [checkCnt := checkCnt + 1].
		(lastOSCallResult succeeded) | (tryCnt > self osCallRetryLimit).
	] whileFalse: [tryCnt := tryCnt + 1].
! !

!ScheduledOSCallMgr methodsFor: 'Control' stamp: 'LL 2/19/2013 16:48'!
clearRequests
	"Clear our requests.  Set them inactive to insure they don't run."

	requests ifNotNil: [:rqs | rqs do: [:r | r hold]].
	requests := Dictionary new.
! !

!ScheduledOSCallMgr methodsFor: 'InstanceVariables' stamp: 'LL 2/19/2013 16:54'!
osCallRetryLimit
	"The number of times to retry command if it failed (or we timed out checking it)."

	osCallRetryLimit isNil ifTrue: [osCallRetryLimit := self class osCallRetryLimitDefault].
	^osCallRetryLimit.
! !

!ScheduledOSCallMgr methodsFor: 'InstanceVariables' stamp: 'LL 2/19/2013 16:54'!
osCallRetryLimit: anInt
	"The number of times to retry command if it failed (or we timed out checking it)."

	osCallRetryLimit := anInt.
! !

!ScheduledOSCallMgr methodsFor: 'InstanceVariables' stamp: 'LL 2/12/2013 11:55'!
osCallTestDelay
	"The milliseconds to delay between checks for completion."

	osCallTestDelay isNil ifTrue: [osCallTestDelay := self class osCallTestDelayDefault].
	^osCallTestDelay.
! !

!ScheduledOSCallMgr methodsFor: 'InstanceVariables' stamp: 'LL 2/12/2013 11:06'!
osCallTestDelay: anInt
	"The milliseconds to delay between checks for completion."

	osCallTestDelay := anInt.
! !

!ScheduledOSCallMgr methodsFor: 'InstanceVariables' stamp: 'LL 2/12/2013 11:56'!
osCallTestLimit
	"The number of times to check for completion."

	osCallTestLimit isNil ifTrue: [osCallTestLimit := self class osCallTestLimitDefault].
	^osCallTestLimit.
! !

!ScheduledOSCallMgr methodsFor: 'InstanceVariables' stamp: 'LL 2/12/2013 11:05'!
osCallTestLimit: anInt
	"The number of times to check for completion."

	osCallTestLimit := anInt.
! !

!ScheduledOSCallMgr methodsFor: 'InstanceVariables' stamp: 'LL 2/7/2013 11:00'!
printOn: aStream
	"Print about us on the stream."

	aStream nextPutAll: 'Title: '; nextPutAll: self title; cr.
	requests do: [:r | r printOn: aStream].
! !

!ScheduledOSCallMgr methodsFor: 'InstanceVariables' stamp: 'LL 2/6/2013 13:50'!
process
	"Answer the process running the OS calls."

	^process.
! !

!ScheduledOSCallMgr methodsFor: 'InstanceVariables' stamp: 'LL 2/19/2013 16:56'!
requests
	"Answer our requests.  A dictionary of instances of ScheduledOSCall that we run at their time."

	requests isNil ifTrue: [requests := Dictionary new].
	^requests.
! !

!ScheduledOSCallMgr methodsFor: 'Control' stamp: 'LL 2/6/2013 14:29'!
run
	"Define and run the process to run the OS calls."

	^self runAt: Processor userBackgroundPriority.
! !

!ScheduledOSCallMgr methodsFor: 'Control' stamp: 'LL 3/1/2013 10:04'!
runAt: priority
	"Define and run the process to run the OS calls.  Re-schedule inactive items when they should run."

	self terminate.
	process := [ | delay date time |
		delay := Delay forSeconds: 1.
		[
			date := Date today.
			time := Time now.
			self requests do: [:r |
				((r date = date) & (r time < time)) ifTrue: [
					r active ifTrue: [self callOS: r] ifFalse: [r schedule].
				].
			].
			true.		
		] whileTrue: [delay wait].
	] forkAt: priority named: self title.
	self class addRunningScheduledOSCallMgr: self.
	^process.
! !

!ScheduledOSCallMgr methodsFor: 'Control' stamp: 'LL 3/1/2013 09:43'!
scheduleAll
	"Schedule all the ScheduledOSCall objects in all the ScheduledOSCallMgr objects."

	self requests do: [:s | s schedule].
! !

!ScheduledOSCallMgr methodsFor: 'Control' stamp: 'LL 3/1/2013 10:03'!
terminate
	"Terminate the process running the OS calls."

	process ifNotNil: [:p | p terminate].
	process := nil.
	self class removeScheduledOSCallMgr: self.
! !

!ScheduledOSCallMgr methodsFor: 'InstanceVariables' stamp: 'LL 2/6/2013 13:37'!
title
	"Answer our title."

	title isNil ifTrue: [title := '?'].
	^title.
! !

!ScheduledOSCallMgr methodsFor: 'InstanceVariables' stamp: 'LL 2/6/2013 13:39'!
title: aString
	"Set our title."

	title := aString.
! !
